@@ -1,11 +1,10 @@
 #[cfg(test)]
 mod data_test;
 
+use anyhow::Result;
 use stun::attributes::*;
 use stun::message::*;
 
-use util::Error;
-
 // Data represents DATA attribute.
 //
 // The DATA attribute is present in all Send and Data indications.  The
@@ -20,7 +19,7 @@ pub struct Data(pub Vec<u8>);
 
 impl Setter for Data {
     // AddTo adds DATA to message.
-    fn add_to(&self, m: &mut Message) -> Result<(), Error> {
+    fn add_to(&self, m: &mut Message) -> Result<()> {
         m.add(ATTR_DATA, &self.0);
         Ok(())
     }
@@ -28,7 +27,7 @@ impl Setter for Data {
 
 impl Getter for Data {
     // GetFrom decodes DATA from message.
-    fn get_from(&mut self, m: &Message) -> Result<(), Error> {
+    fn get_from(&mut self, m: &Message) -> Result<()> {
         self.0 = m.get(ATTR_DATA)?;
         Ok(())
     }
