@@ -1,12 +1,11 @@
 #[cfg(test)]
 mod rsrvtoken_test;
 
+use anyhow::Result;
 use stun::attributes::*;
 use stun::checks::*;
 use stun::message::*;
 
-use util::Error;
-
 // ReservationToken represents RESERVATION-TOKEN attribute.
 //
 // The RESERVATION-TOKEN attribute contains a token that uniquely
@@ -24,7 +23,7 @@ const RESERVATION_TOKEN_SIZE: usize = 8; // 8 bytes
 
 impl Setter for ReservationToken {
     // AddTo adds RESERVATION-TOKEN to message.
-    fn add_to(&self, m: &mut Message) -> Result<(), Error> {
+    fn add_to(&self, m: &mut Message) -> Result<()> {
         check_size(ATTR_RESERVATION_TOKEN, self.0.len(), RESERVATION_TOKEN_SIZE)?;
         m.add(ATTR_RESERVATION_TOKEN, &self.0);
         Ok(())
@@ -33,7 +32,7 @@ impl Setter for ReservationToken {
 
 impl Getter for ReservationToken {
     // GetFrom decodes RESERVATION-TOKEN from message.
-    fn get_from(&mut self, m: &Message) -> Result<(), Error> {
+    fn get_from(&mut self, m: &Message) -> Result<()> {
         let v = m.get(ATTR_RESERVATION_TOKEN)?;
         check_size(ATTR_RESERVATION_TOKEN, v.len(), RESERVATION_TOKEN_SIZE)?;
         self.0 = v;
