@@ -2,24 +2,24 @@ pub mod relay_none;
 pub mod relay_range;
 pub mod relay_static;
 
-use util::{Conn, Error};
+use util::Conn;
 
+use anyhow::Result;
+use async_trait::async_trait;
 use std::net::SocketAddr;
 use std::sync::Arc;
 
-use async_trait::async_trait;
-
 // RelayAddressGenerator is used to generate a RelayAddress when creating an allocation.
 // You can use one of the provided ones or provide your own.
 #[async_trait]
 pub trait RelayAddressGenerator {
     // validate confirms that the RelayAddressGenerator is properly initialized
-    fn validate(&self) -> Result<(), Error>;
+    fn validate(&self) -> Result<()>;
 
     // Allocate a RelayAddress
     async fn allocate_conn(
         &self,
         use_ipv4: bool,
         requested_port: u16,
-    ) -> Result<(Arc<dyn Conn + Send + Sync>, SocketAddr), Error>;
+    ) -> Result<(Arc<dyn Conn + Send + Sync>, SocketAddr)>;
 }
