@@ -21,7 +21,7 @@ const INBOUND_MTU: usize = 1500;
 
 /// Server is an instance of the TURN Server
 pub struct Server {
-    auth_handler: Arc<Box<dyn AuthHandler + Send + Sync>>,
+    auth_handler: Arc<dyn AuthHandler + Send + Sync>,
     realm: String,
     channel_bind_timeout: Duration,
     pub(crate) nonces: Arc<Mutex<HashMap<String, Instant>>>,
@@ -79,7 +79,7 @@ impl Server {
         conn: Arc<dyn Conn + Send + Sync>,
         allocation_manager: Arc<Manager>,
         nonces: Arc<Mutex<HashMap<String, Instant>>>,
-        auth_handler: Arc<Box<dyn AuthHandler + Send + Sync>>,
+        auth_handler: Arc<dyn AuthHandler + Send + Sync>,
         realm: String,
         channel_bind_timeout: Duration,
         mut shutdown_rx: watch::Receiver<bool>,
